@@ -8,18 +8,22 @@
 from nonebot import get_driver
 from i2llservice.client import I2LLClient
 from .config import Config
+from i2cylib.utils.logger import Logger
 
 DRIVER = get_driver()
 GLOBAL_CONFIG = DRIVER.config
 LL_CONFIG = Config.parse_obj(GLOBAL_CONFIG)
 
-print("test i2ll config:")
-print(" i2ll_host: {}".format(LL_CONFIG.i2ll_host))
-print(" i2ll_port: {}".format(LL_CONFIG.i2ll_port))
-print(" i2ll_psk: {}".format(LL_CONFIG.i2ll_psk))
-print(" i2ll_timeout: {}".format(LL_CONFIG.i2ll_timeout))
-print(" i2ll_buffer_size: {}".format(LL_CONFIG.i2ll_clt_buffer))
-
+if LL_CONFIG.i2ll_debug:
+    print("test i2ll config:")
+    print(" i2ll_host: {}".format(LL_CONFIG.i2ll_host))
+    print(" i2ll_port: {}".format(LL_CONFIG.i2ll_port))
+    print(" i2ll_psk: {}".format(LL_CONFIG.i2ll_psk))
+    print(" i2ll_timeout: {}".format(LL_CONFIG.i2ll_timeout))
+    print(" i2ll_buffer_size: {}".format(LL_CONFIG.i2ll_clt_buffer))
+    logger = Logger(level="DEBUG")
+else:
+    logger = Logger(level="INFO")
 
 LL_CLT = I2LLClient(LL_CONFIG.i2ll_host, LL_CONFIG.i2ll_port, LL_CONFIG.i2ll_psk,
                     watchdog_timeout=LL_CONFIG.i2ll_timeout,
