@@ -27,7 +27,7 @@ NLP_PROC = NlpUnit()
 
 @matcher.handle()
 async def unlock_by_group_member(bot: Bot, event: GroupMessage):
-    group_id = event.get_user_id()
+    group_id = event.dict()["group"]["id"]
     msg = event.get_plaintext()
     if NLP_PROC.is_calling(msg) and group_id in GROUP_INDEX_TREE.keys():
 
